@@ -18,6 +18,8 @@
 
 #include "3rdparty/qtsingleapplication/QtSingleApplication"
 
+#include "DesktopApplicationLaunch.hpp"
+
 namespace rstudio {
 namespace desktop {
 
@@ -27,9 +29,9 @@ class PosixApplication : public QtSingleApplication
 public:
 
    PosixApplication(QString appName, int& argc, char* argv[])
-    : QtSingleApplication(appName, argc, argv)
+    : QtSingleApplication(appName, argc, argv),
+      pAppLauncher_(NULL)
    {
-      setApplicationName(appName);
    }
 
    QString startupOpenFileRequest() const
@@ -37,6 +39,11 @@ public:
       return startupOpenFileRequest_;
    }
 
+   void setAppLauncher(ApplicationLaunch* pAppLauncher)
+   {
+       pAppLauncher_ = pAppLauncher;
+   }
+
 signals:
     void openFileRequest(QString filename);
 
@@ -45,11 +52,10 @@ protected:
 
 private:
     QString startupOpenFileRequest_;
-
+    ApplicationLaunch* pAppLauncher_;
 };
 
 
-
 } // namespace desktop
 } // namespace rstudio
 
