@@ -18,6 +18,8 @@
 
 #include <string>
 
+#include <boost/asio/io_service.hpp>
+
 #include <core/system/System.hpp>
 #include <core/LogWriter.hpp>
 
@@ -27,14 +29,6 @@
 
 #include "MonitorConstants.hpp"
 
-// forward declaration; boost/asio/io_service may cause errors if included more
-// than once (Boost 1.50 on Win x64 only)
-namespace RSTUDIO_BOOST_NAMESPACE {
-namespace asio {
-   class io_service;
-}
-}
-
 namespace rstudio {
 namespace monitor {
 
