@@ -1,7 +1,7 @@
 /*
  * SessionOptions.cpp
  *
- * Copyright (C) 2009-12 by RStudio, Inc.
+ * Copyright (C) 2009-17 by RStudio, Inc.
  *
  * Unless you have received this program directly from RStudio pursuant
  * to the terms of a commercial license agreement with RStudio, then
@@ -77,7 +77,7 @@ Options& options()
    return instance ;
 }
    
-core::ProgramStatus Options::read(int argc, char * const argv[])
+core::ProgramStatus Options::read(int argc, char * const argv[], std::ostream& osWarnings)
 {
    using namespace boost::program_options ;
    
@@ -101,8 +101,12 @@ core::ProgramStatus Options::read(int argc, char * const argv[])
 
    // detect running in x64 directory and tweak resource path
 #ifdef _WIN32
+   bool is64 = false;
    if (resourcePath_.complete("x64").exists())
+   {
+      is64 = true;
       resourcePath_ = resourcePath_.parent();
+   }
 #endif
    
    // run tests flag
@@ -116,7 +120,7 @@ core::ProgramStatus Options::read(int argc, char * const argv[])
    options_description verify("verify");
    verify.add_options()
      (kVerifyInstallationSessionOption,
-     value<bool>(&verifyInstallation_)->default_value(false)->implicit_value(true),
+     value<bool>(&verifyInstallation_)->default_value(false),
      "verify the current installation");
 
    // program - name and execution
@@ -200,7 +204,22 @@ core::ProgramStatus Options::read(int argc, char * const argv[])
        "default directory for new projects")
       ("show-help-home",
        value<bool>(&showHelpHome_)->default_value(false),
-         "show help home page at startup");
+         "show help home page at startup")
+      ("session-default-console-term",
+       value<std::string>(&defaultConsoleTerm_)->default_value("xterm-256color"),
+       "default TERM setting for R console")
+      ("session-default-clicolor-force",
+       value<bool>(&defaultCliColorForce_)->default_value(true),
+       "default CLICOLOR_FORCE setting for R console")
+      ("session-quit-child-processes-on-exit",
+       value<bool>(&quitChildProcessesOnExit_)->default_value(false),
+       "quit child processes on session exit")
+      ("session-first-project-template-path",
+       value<std::string>(&firstProjectTemplatePath_)->default_value(""),
+       "first project template path")
+      ("default-rsconnect-server",
+       value<std::string>(&defaultRSConnectServer_)->default_value(""),
+       "default RStudio Connect server URL");
 
    // allow options
    options_description allow("allow");
@@ -220,9 +239,15 @@ core::ProgramStatus Options::read(int argc, char * const argv[])
       ("allow-shell",
          value<bool>(&allowShell_)->default_value(true),
          "allow access to shell dialog")
+      ("allow-terminal-websockets",
+         value<bool>(&allowTerminalWebsockets_)->default_value(true),
+         "allow connection to terminal sessions with websockets")
       ("allow-file-downloads",
          value<bool>(&allowFileDownloads_)->default_value(true),
          "allow file downloads from the files pane")
+      ("allow-file-uploads",
+         value<bool>(&allowFileUploads_)->default_value(true),
+         "allow file uploads from the files pane")
       ("allow-remove-public-folder",
          value<bool>(&allowRemovePublicFolder_)->default_value(true),
          "allow removal of the user public folder")
@@ -237,7 +262,10 @@ core::ProgramStatus Options::read(int argc, char * const argv[])
         "allow publishing content")
       ("allow-presentation-commands",
          value<bool>(&allowPresentationCommands_)->default_value(false),
-       "allow presentation commands");
+       "allow presentation commands")
+      ("allow-full-ui",
+         value<bool>(&allowFullUI_)->default_value(true),
+       "allow full standalone ui mode");
 
    // r options
    bool rShellEscape; // no longer works but don't want to break any
@@ -334,7 +362,17 @@ core::ProgramStatus Options::read(int argc, char * const argv[])
       ("external-libclang-headers-path",
         value<std::string>(&libclangHeadersPath_)->default_value(
                                        "resources/libclang/builtin-headers"),
-        "Path to libclang builtin headers");
+        "Path to libclang builtin headers")
+      ("external-winpty-path",
+        value<std::string>(&winptyPath_)->default_value("bin"),
+         "Path to winpty binaries");
+   
+   // git options
+   options_description git("git");
+   git.add_options()
+         ("git-commit-large-file-size",
+          value<int>(&gitCommitLargeFileSize_)->default_value(5 * 1024 * 1024),
+          "warn when attempting to commit files larger than this size (in bytes; set 0 to disable)");
 
    // user options (default user identity to current username)
    std::string currentUsername = core::system::username();
@@ -352,7 +390,10 @@ core::ProgramStatus Options::read(int argc, char * const argv[])
        "active project" )
       (kScopeSessionOption "," kScopeSessionOptionShort,
         value<std::string>(&scopeId)->default_value(""),
-       "session scope id");
+       "session scope id")
+      ("launcher-token",
+       value<std::string>(&launcherToken_)->default_value(""),
+       "token identifying session launcher");
 
    // overlay options
    options_description overlay("overlay");
@@ -377,6 +418,7 @@ core::ProgramStatus Options::read(int argc, char * const argv[])
    optionsDesc.commandLine.add(r);
    optionsDesc.commandLine.add(limits);
    optionsDesc.commandLine.add(external);
+   optionsDesc.commandLine.add(git);
    optionsDesc.commandLine.add(user);
    optionsDesc.commandLine.add(overlay);
 
@@ -414,7 +456,7 @@ core::ProgramStatus Options::read(int argc, char * const argv[])
    // call overlay hooks
    resolveOverlayOptions();
    std::string errMsg;
-   if (!validateOverlayOptions(&errMsg))
+   if (!validateOverlayOptions(&errMsg, osWarnings))
    {
       program_options::reportError(errMsg, ERROR_LOCATION);
       return ProgramStatus::exitFailure();
@@ -497,6 +539,27 @@ core::ProgramStatus Options::read(int argc, char * const argv[])
    resolvePath(resourcePath_, &msysSshPath_);
    resolvePath(resourcePath_, &sumatraPath_);
    resolvePath(resourcePath_, &winutilsPath_);
+   resolvePath(resourcePath_, &winptyPath_);
+
+   // winpty.dll lives next to rsession.exe on a full install; otherwise
+   // it lives in a directory named 32 or 64
+   core::FilePath pty(winptyPath_);
+   std::string completion;
+   if (pty.isWithin(resourcePath_))
+   {
+      if (is64)
+         completion = "x64/winpty.dll";
+      else
+         completion = "winpty.dll";
+   }
+   else
+   {
+      if (is64)
+         completion = "64/bin/winpty.dll";
+      else
+         completion = "32/bin/winpty.dll";
+   }
+   winptyPath_ = pty.complete(completion).absolutePath();
 #endif
    resolvePath(resourcePath_, &hunspellDictionariesPath_);
    resolvePath(resourcePath_, &mathjaxPath_);
@@ -622,7 +685,7 @@ void Options::resolvePostbackPath(const FilePath& resourcePath,
    // On OSX we keep the postback scripts over in the MacOS directory
    // rather than in the Resources directory -- make this adjustment
    // when the default postback path has been passed
-   if (*pPath == kDefaultPostbackPath)
+   if (*pPath == kDefaultPostbackPath && programMode() == kSessionProgramModeDesktop)
    {
       FilePath path = resourcePath.parent().complete("MacOS/postback/rpostback");
       *pPath = path.absolutePath();
@@ -636,7 +699,7 @@ void Options::resolvePostbackPath(const FilePath& resourcePath,
 void Options::resolvePandocPath(const FilePath& resourcePath,
                                 std::string* pPath)
 {
-   if (*pPath == kDefaultPandocPath)
+   if (*pPath == kDefaultPandocPath && programMode() == kSessionProgramModeDesktop)
    {
       FilePath path = resourcePath.parent().complete("MacOS/pandoc");
       *pPath = path.absolutePath();
@@ -650,7 +713,7 @@ void Options::resolvePandocPath(const FilePath& resourcePath,
 void Options::resolveRsclangPath(const FilePath& resourcePath,
                                  std::string* pPath)
 {
-   if (*pPath == kDefaultRsclangPath)
+   if (*pPath == kDefaultRsclangPath && programMode() == kSessionProgramModeDesktop)
    {
       FilePath path = resourcePath.parent().complete("MacOS/rsclang");
       *pPath = path.absolutePath();
