@@ -1,7 +1,7 @@
 /*
  * SessionUserSettings.cpp
  *
- * Copyright (C) 2009-15 by RStudio, Inc.
+ * Copyright (C) 2009-17 by RStudio, Inc.
  *
  * Unless you have received this program directly from RStudio pursuant
  * to the terms of a commercial license agreement with RStudio, then
@@ -23,6 +23,8 @@
 #include <core/Error.hpp>
 #include <core/FilePath.hpp>
 #include <core/system/System.hpp>
+#include <core/system/Environment.hpp>
+#include <core/system/Process.hpp>
 
 #include <core/r_util/RSessionContext.hpp>
 
@@ -67,6 +69,9 @@ const char * const kAlwaysSaveHistory = "alwaysSaveHistory";
 const char * const kRemoveHistoryDuplicates = "removeHistoryDuplicates";
 const char * const kLineEndings = "lineEndingConversion";
 const char * const kUseNewlineInMakefiles = "newlineInMakefiles";
+const char * const kDefaultTerminalShell = "defaultTerminalShell";
+const char * const kCustomShellCommand = "customShellCommand";
+const char * const kCustomShellOptions = "customShellOptions";
 
 template <typename T>
 T readPref(const json::Object& prefs,
@@ -182,6 +187,25 @@ SEXP rs_writeUiPref(SEXP prefName, SEXP value)
    return R_NilValue;
 }
 
+SEXP rs_removeUiPref(SEXP prefName)
+{
+   // extract name of preference to write
+   std::string pref = r::sexp::safeAsString(prefName, "");
+   if (pref.empty())
+      return R_NilValue;
+   
+   json::Object uiPrefs = userSettings().uiPrefs();
+   json::Object::iterator it = uiPrefs.find(pref);
+   if (it != uiPrefs.end())
+   {
+      uiPrefs.erase(it);
+   }
+
+   userSettings().setUiPrefs(uiPrefs);
+
+   return R_NilValue;
+}
+
 } // anonymous namespace
    
 UserSettings& userSettings()
@@ -213,17 +237,9 @@ Error UserSettings::initialize()
       return error;
 
    // register routines for reading/writing UI prefs from R code
-   R_CallMethodDef readUiPrefMethodDef ;
-   readUiPrefMethodDef.name = "rs_readUiPref";
-   readUiPrefMethodDef.fun = (DL_FUNC) rs_readUiPref;
-   readUiPrefMethodDef.numArgs = 1;
-   r::routines::addCallMethod(readUiPrefMethodDef);
-
-   R_CallMethodDef writeUiPrefMethodDef ;
-   writeUiPrefMethodDef.name = "rs_writeUiPref";
-   writeUiPrefMethodDef.fun = (DL_FUNC) rs_writeUiPref;
-   writeUiPrefMethodDef.numArgs = 2;
-   r::routines::addCallMethod(writeUiPrefMethodDef);
+   RS_REGISTER_CALL_METHOD(rs_readUiPref, 1);
+   RS_REGISTER_CALL_METHOD(rs_writeUiPref, 2);
+   RS_REGISTER_CALL_METHOD(rs_removeUiPref, 1);
 
    // make sure we have a context id
    if (contextId().empty())
@@ -381,6 +397,31 @@ void UserSettings::updatePrefsCache(const json::Object& prefs) const
 
    bool enableStyleDiagnostics = readPref<bool>(prefs, "enable_style_diagnostics", false);
    pEnableStyleDiagnostics_.reset(new bool(enableStyleDiagnostics));
+
+   int ansiConsoleMode = readPref<int>(prefs, "ansi_console_mode", core::text::AnsiColorOn);
+   pAnsiConsoleMode_.reset(new int(ansiConsoleMode));
+
+   int terminalWebsockets = readPref<bool>(prefs, "terminal_websockets", true);
+   pTerminalWebsockets_.reset(new bool(terminalWebsockets));
+
+   bool terminalAutoclose = readPref<bool>(prefs, "terminal_autoclose", true);
+   pTerminalAutoclose_.reset(new bool(terminalAutoclose));
+
+   bool terminalTrackEnv = readPref<bool>(prefs, "terminal_track_env", true);
+   pTerminalTrackEnv_.reset(new bool(terminalTrackEnv));
+
+   int terminalBusyMode = readPref<int>(prefs, "busy_detection", core::system::busy_detection::Always);
+   pTerminalBusyMode_.reset(new int(terminalBusyMode));
+
+   core::json::Array defWhitelist;
+   defWhitelist.push_back("tmux");
+   defWhitelist.push_back("screen");
+   json::Array terminalBusyWhitelist = readPref<core::json::Array>(prefs,
+                                                                   "busy_whitelist",
+                                                                   defWhitelist);
+   pTerminalBusyWhitelist_.reset(new json::Array(terminalBusyWhitelist));
+
+   syncConsoleColorEnv();
 }
 
 
@@ -537,12 +578,89 @@ void UserSettings::setShowLastDotValue(bool show)
    settings_.set("showLastDotValue", show);
 }
 
+console_process::TerminalShell::TerminalShellType UserSettings::defaultTerminalShellValue() const
+{
+   return static_cast<console_process::TerminalShell::TerminalShellType>(
+            settings_.getInt(kDefaultTerminalShell,
+               static_cast<int>(console_process::TerminalShell::DefaultShell)));
+}
+
+void UserSettings::setDefaultTerminalShellValue(
+      console_process::TerminalShell::TerminalShellType shell)
+{
+   settings_.set(kDefaultTerminalShell, static_cast<int>(shell));
+}
+
+core::FilePath UserSettings::customShellCommand() const
+{
+   return core::FilePath(settings_.get(kCustomShellCommand, ""));
+}
+
+void UserSettings::setCustomShellCommand(const std::string& commandPath)
+{
+   settings_.set(kCustomShellCommand, commandPath);
+}
+
+std::string UserSettings::customShellOptions() const
+{
+   return settings_.get(kCustomShellOptions, "");
+}
+
+void UserSettings::setCustomShellOptions(const std::string& options)
+{
+   settings_.set(kCustomShellOptions, options);
+}
 
 core::FilePath UserSettings::initialWorkingDirectory() const
 {
    return getWorkingDirectoryValue(kInitialWorkingDirectory);
 }
 
+std::string UserSettings::initialWorkingDirectory(const std::string& defaultStr) const
+{
+   if (!settings_.contains(kInitialWorkingDirectory))
+      return defaultStr;
+
+   return initialWorkingDirectory().absolutePath();
+}
+
+core::text::AnsiCodeMode UserSettings::ansiConsoleMode() const
+{
+   return static_cast<core::text::AnsiCodeMode>(readUiPref<int>(pAnsiConsoleMode_));
+}
+
+bool UserSettings::terminalWebsockets() const
+{
+   return readUiPref<bool>(pTerminalWebsockets_);
+}
+
+bool UserSettings::terminalAutoclose() const
+{
+   return readUiPref<bool>(pTerminalAutoclose_);
+}
+
+bool UserSettings::terminalTrackEnv() const
+{
+   return readUiPref<bool>(pTerminalTrackEnv_);
+}
+
+core::system::busy_detection::Mode UserSettings::terminalBusyMode() const
+{
+   return static_cast<core::system::busy_detection::Mode>(readUiPref<int>(pTerminalBusyMode_));
+}
+
+std::vector<std::string> UserSettings::terminalBusyWhitelist() const
+{
+   json::Array whitelistJson = readUiPref<json::Array>(pTerminalBusyWhitelist_);
+   std::vector<std::string> whitelist;
+   BOOST_FOREACH(const json::Value& exeJson, whitelistJson)
+   {
+      if (json::isType<std::string>(exeJson))
+         whitelist.push_back(exeJson.get_str());
+   }
+   return whitelist;
+}
+
 CRANMirror UserSettings::cranMirror() const
 {
    // get the settings
@@ -680,16 +798,6 @@ void UserSettings::setVcsTerminalPath(const FilePath& terminalPath)
    settings_.set("vcsTerminalPath", terminalPath.absolutePath());
 }
 
-bool UserSettings::vcsUseGitBash() const
-{
-   return settings_.getBool("vcsUseGitBash", true);
-}
-
-void UserSettings::setVcsUseGitBash(bool useGitBash)
-{
-   settings_.set("vcsUseGitBash", useGitBash);
-}
-
 bool UserSettings::cleanTexi2DviOutput() const
 {
    return settings_.getBool("cleanTexi2DviOutput", true);
@@ -891,6 +999,32 @@ void UserSettings::setReuseSessionsForProjectLinks(bool reuse)
    settings_.set(kReuseSessionsForProjectLinksSettings, reuse);
 }
 
+void UserSettings::syncConsoleColorEnv() const
+{
+   // Use rsession alias to avoid collision with 'session'
+   // object brought in by Catch
+   namespace rsession = rstudio::session;
+   using namespace rsession;
+
+   // Mirror ansi_color_mode user preference with RSTUDIO_CONSOLE_COLOR
+   // environment variable so it can be inherited by spawned R processes, such
+   // as package builds, which cannot query RStudio IDE settings.
+   if (userSettings().ansiConsoleMode() == core::text::AnsiColorOn)
+   {
+      core::system::setenv("RSTUDIO_CONSOLE_COLOR", "256");
+
+      if (rsession::options().defaultConsoleTerm().length() > 0)
+         core::system::setenv("TERM", rsession::options().defaultConsoleTerm());
+      if (rsession::options().defaultCliColorForce())
+         core::system::setenv("CLICOLOR_FORCE", "1");
+   }
+   else
+   {
+      core::system::unsetenv("RSTUDIO_CONSOLE_COLOR");
+      core::system::unsetenv("TERM");
+      core::system::unsetenv("CLICOLOR_FORCE");
+   }
+}
 
 } // namespace session
 } // namespace rstudio
