@@ -528,6 +528,6 @@ Error getCppCompletions(const core::json::JsonRpcRequest& request,
 
 } // namespace clang
 } // namespace modules
-} // namesapce session
+} // namespace session
 } // namespace rstudio
 
