@@ -26,7 +26,7 @@ void installTutorial(const core::FilePath& tutorialPath,
 
 } // namespace presentation
 } // namespace modules
-} // namesapce session
+} // namespace session
 } // namespace rstudio
 
 #endif // SESSION_PRESENTATION_TUTORIAL_INSTALLER_HPP
