@@ -37,13 +37,15 @@ bool rmarkdownPackageAvailable();
 
 bool knitParamsAvailable();
 
+bool knitWorkingDirAvailable();
+
 core::Error evaluateRmdParams(const std::string& docId);
 
 core::Error initialize();
 
 } // namespace rmarkdown
 } // namepace handlers
-} // namesapce session
+} // namespace session
 } // namespace rstudio
 
 #endif // SESSION_SESSION_RMARKDOWN_HPP
