@@ -297,12 +297,18 @@ public class Application implements ApplicationEventHandlers
       globalDisplay_.openWindow(server_.getApplicationURL("agreement"));
    }
    
+   @Handler
+   public void onRstudioCommunityForum()
+   {
+      globalDisplay_.openRStudioLink("community-forum");
+   }
+   
    @Handler
    public void onRstudioSupport()
    {
       globalDisplay_.openRStudioLink("support");
    }
-   
+
    @Handler
    public void onRstudioAgreement()
    {
