@@ -399,7 +399,8 @@ public class Workbench implements BusyHandler,
             {
                Desktop.getFrame().openTerminal(options.getTerminalPath(),
                      options.getWorkingDirectory(),
-                     options.getExtraPathEntries());
+                     options.getExtraPathEntries(),
+                     options.getShellType());
             }
          });
       }
