@@ -1,7 +1,7 @@
 /*
  * AceEditorWidget.java
  *
- * Copyright (C) 2009-12 by RStudio, Inc.
+ * Copyright (C) 2009-17 by RStudio, Inc.
  *
  * Unless you have received this program directly from RStudio pursuant
  * to the terms of a commercial license agreement with RStudio, then
@@ -89,8 +89,8 @@ public class AceEditorWidget extends Composite
       setSize("100%", "100%");
 
       capturingHandlers_ = new HandlerManager(this);
-      addEventListener(getElement(), "keydown", capturingHandlers_);
-      addEventListener(getElement(), "keyup", capturingHandlers_);
+      addEventListener(getElement(), "keydown",  capturingHandlers_);
+      addEventListener(getElement(), "keyup",    capturingHandlers_);
       addEventListener(getElement(), "keypress", capturingHandlers_);
 
       addStyleName("loading");
@@ -270,6 +270,19 @@ public class AceEditorWidget extends Composite
                }
             }));
       
+      aceEventHandlers_.add(AceEditorNative.addEventListener(
+            editor_,
+            "changeSelection",
+            new CommandWithArg<Void>()
+            {
+               @Override
+               public void execute(Void event)
+               {
+                  fireEvent(new AceSelectionChangedEvent());
+               }
+            }));
+      
+      
       addAttachHandler(new AttachEvent.Handler()
       {
          @Override
@@ -529,7 +542,7 @@ public class AceEditorWidget extends Composite
    {
       return addHandler(handler, KeyUpEvent.getType());
    }
-
+   
    public HandlerRegistration addCapturingKeyDownHandler(KeyDownHandler handler)
    {
       return capturingHandlers_.addHandler(KeyDownEvent.getType(), handler);
@@ -575,6 +588,11 @@ public class AceEditorWidget extends Composite
       return addHandler(handler, AceClickEvent.TYPE);
    }
    
+   public HandlerRegistration addSelectionChangedHandler(AceSelectionChangedEvent.Handler handler)
+   {
+      return addHandler(handler, AceSelectionChangedEvent.TYPE);
+   }
+   
    public void forceResize()
    {
       editor_.getRenderer().onResize(true);
